/*
 * Project name:
     Button (Demonstration of using Button Library)
 * Copyright:
     (c) Mikroelektronika, 2009.
 * Revision History:
     20080110:
       - initial release;
       - 20090818 - Slavisa Zlatanovic;
 * Description:
     This program demonstrates usage of the on-board button as PORTB input.
     On every PB0 one-to-zero transition PORTC is inverted.
 * Test configuration:
     MCU:             ATmega16
                      http://www.atmel.com/dyn/resources/prod_documents/doc2466.pdf
     Dev.Board:       EasyAVR6
                      http://www.mikroe.com/en/tools/easyavr6/
     Oscillator:      External Clock 08.0000 MHz
     Ext. Modules:    -
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/en/compilers/mikroc/avr/
 * NOTES:
     - Make sure you turn ON the PORTC LEDs(SW8.3).
     - Put button jumper (J13) into VCC position and pull-down PORTB.
*/

// Button connections
sbit Button_Pin           at PINB.B0;            // Input pin, PINx register is used
sbit Button_Pin_Direction at DDRB.B0;
// End Button connections

bit oldstate;                                    // Old state flag

void main() {

  Button_Pin_Direction = 0;                      // Set pin as input

  DDRC  = 0xFF;                                  // Configure PORTC as output
  PORTC = 0xAA;                                  // Initial PORTC value
  
  oldstate = 0;


  do {
    if (Button(&PINB, 0, 1, 1)) {                // Detect logical one
      oldstate = 1;                              // Update flag
    }
    if (oldstate && Button(&PINB, 0, 1, 0)) {    // Detect one-to-zero transition
      PORTC = ~PORTC;                            // Invert PORTC
      oldstate = 0;                              // Update flag
    }
  } while(1);                                    // Endless loop
}
