/*
 * Project name:
     Eeprom (Demonstration of using EEPROM Library) 
 * Copyright:
     (c) Mikroelektronika, 2009.
 * Revision History:
     20080930:
       - initial release;
       - 20090818 - Slavisa Zlatanovic;
 * Description:
     This is a demonstration of using library functions for handling of the
     AVR's internal EEPROM module. First, some data is written to EEPROM
     in byte and block mode; then the data is read from the same locations and 
     displayed on PORTA, PORTB and PORTC.
 * Test configuration:
     MCU:             ATmega16
                      http://www.atmel.com/dyn/resources/prod_documents/doc2466.pdf
     Dev.Board:       EasyAVR6
                      http://www.mikroe.com/en/tools/easyavr6/
     Oscillator:      External Clock 08.0000 MHz
     Ext. Modules:    -
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/en/compilers/mikroc/avr/
 * NOTES:
      - Turn on PORTA, PORTB and PORTC LEDs(SW8.2, SW8.2 and SW8.3).
*/


char ii;                                   // Loop variable

void main(){
   DDRA = 0xFF;
   DDRB = 0xFF;
   DDRC = 0xFF;
   
   for(ii = 0; ii < 32; ii++)              // Fill data buffer
     EEPROM_Write(0x100+ii, ii);           // Write data to address 0x100+ii

   EEPROM_Write(0x02,0xAA);                // Write some data at address 2
   EEPROM_Write(0x150,0x55);               // Write some data at address 0x150

   Delay_ms(1000);                         // Blink PORTA and PORTB diodes
   PORTA = 0xFF;                           // to indicate reading start
   PORTB = 0xFF;
   Delay_ms(1000);
   PORTA = 0x00;
   PORTB = 0x00;
   Delay_ms(1000);

   PORTA = EEPROM_Read(0x02);              // Read data from address 2 and display it on PORT0
   PORTB = EEPROM_Read(0x150);             // Read data from address 0x150 and display it on PORT1

   Delay_ms(1000);

   for(ii = 0; ii < 32; ii++) {            // Read 32 bytes block from address 0x100
     PORTC = EEPROM_Read(0x100+ii);        // and display data on PORT2
     Delay_ms(100);
   }
}
