/*
 * Project name:
     COG_Lcd_Test (Simple demonstration of the SPI Lcd 4-bit Library functions)
 * Copyright:
     (c) Mikroelektronika, 2009.
 * Revision History:
     20090505:
       - initial release;
       - 20090818 - Slavisa Zlatanovic;
 * Description:
     This is a simple demonstration of SPI Lcd 4-bit library functions.
     SPI Lcd Library sends commands to Port Expander and it controls
     Port Expander's output Port1 (connected to Serial LCD).
 * Test configuration:
     MCU:             ATmega16
                      http://www.atmel.com/dyn/resources/prod_documents/doc2466.pdf
     Dev.Board:       EasyAVR6
                      http://www.mikroe.com/en/tools/easyavr6/
     Oscillator:      External Clock 08.0000 MHz
     Ext. Modules:    -
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/en/compilers/mikroc/avr/
 * NOTES:
     - Turn on switches SW9.7, SW9.8, SW6.1, SW6.5, SW6.7 SW7.1 and SW7.5.
     - Turn on COG LCD 2x16 switches SW10.1, SW10.2, SW10.3, SW10.4, SW10.5 and SW10.6.
*/

char *text = "www.mikroe.com";

// Port Expander module connections
sbit  SPExpanderRST at PORTB2_bit;
sbit  SPExpanderCS  at PORTB1_bit;
sbit  SPExpanderRST_Direction at DDB2_bit;
sbit  SPExpanderCS_Direction  at DDB1_bit;
// End Port Expander module connections

char i;                                  // Loop variable

void Move_Delay() {                      // Function used for text moving
  Delay_ms(500);                         // You can change the moving speed here
}

void main() {

  // Port Expander Library uses SPI1 module
  SPI1_Init();                           // Initialize SPI module used with PortExpander

  SPI_Lcd_Config(0);                     // Initialize Lcd over SPI interface
  SPI_Lcd_Cmd(_LCD_CLEAR);               // Clear display
  SPI_Lcd_Cmd(_LCD_CURSOR_OFF);          // Turn cursor off
  SPI_Lcd_Out(1,1, "mikroElektronika");  // Print text to Lcd, 1st row, 1st column
  SPI_Lcd_Out(2,2, text);                // Print text to Lcd, 2nd row, 2nd column

  Delay_1sec();
  Delay_1sec();

    // Moving text
  for(i=0; i<4; i++) {                   // Move text to the right 4 times
    SPI_Lcd_Cmd(_LCD_SHIFT_RIGHT);
    Move_Delay();
  }

  while(1) {                             // Endless loop
    for(i=0; i<8; i++) {                 // Move text to the left 7 times
      SPI_Lcd_Cmd(_LCD_SHIFT_LEFT);
      Move_Delay();
    }

    for(i=0; i<8; i++) {                 // Move text to the right 7 times
      SPI_Lcd_Cmd(_LCD_SHIFT_RIGHT);
      Move_Delay();
    }
  }

}
