/*
 * Project name:
     Timer2_Interrupt (Using Timer2 to obtain interrupts)
 * Copyright:
     (c) Mikroelektronika, 2009.
 * Revision History:
     20080930:
       - initial release;
       - 20090818 - Slavisa Zlatanovic;
 * Description:
     This code demonstrates how to use Timer2 and it's interrupt.
     Program toggles LEDs on PORTB.
 * Test configuration:
     MCU:             ATmega16
                      http://www.atmel.com/dyn/resources/prod_documents/doc2466.pdf
     Dev.Board:       EasyAVR6
                      http://www.mikroe.com/en/tools/easyavr6/
     Oscillator:      External Clock 8.0000 MHz
     Ext. Modules:    -
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/en/compilers/mikroc/avr/
 * NOTES:
     - Turn on LEDs on PORTB (SW8.2).
*/

const char _THRESHOLD = 20;
char counter;

void Timer2Overflow_ISR() org IVT_ADDR_TIMER2_OVF {

  if (counter >= _THRESHOLD) {
    PORTB = ~PORTB;             // toggle PORTB
    counter = 0;                // reset counter
  }
  else
    counter++;                  // increment counter

}

void main() {

  DDRB   = 0xFF;                // set PORTB as output
  PORTB  = 0;                   // clear PORTB

  SREG_I_bit = 1;               // interrupt enable
  TOIE2_bit  = 1;               // timer2 overflow interrupt enable
  TCCR2  = 7;                   // start timer with 1024 prescaler

  while (1)                     // endless loop, port is changed inside Interrupt Service Routine (ISR)
    ;
}
